@@ -271,6 +271,10 @@ impl Encode for StartEncoderChain {
     fn requiring_bytes(&self) -> ByteCount {
         ByteCount::Finite(0)
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        Ok(())
+    }
 }
 impl ExactBytesEncode for StartEncoderChain {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -315,6 +319,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.b.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.b.cancel())
+    }
 }
 impl<E0, E1, T0> Encode for EncoderChain<E0, E1, (T0,)>
 where
@@ -338,6 +346,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1> Encode for EncoderChain<E0, E1, (T0, T1)>
 where
@@ -361,6 +373,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1, T2> Encode for EncoderChain<E0, E1, (T0, T1, T2)>
 where
@@ -384,6 +400,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1, T2, T3> Encode for EncoderChain<E0, E1, (T0, T1, T2, T3)>
 where
@@ -407,6 +427,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1, T2, T3, T4> Encode for EncoderChain<E0, E1, (T0, T1, T2, T3, T4)>
 where
@@ -430,6 +454,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1, T2, T3, T4, T5> Encode for EncoderChain<E0, E1, (T0, T1, T2, T3, T4, T5)>
 where
@@ -454,6 +482,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T0, T1, T2, T3, T4, T5, T6> Encode
     for EncoderChain<E0, E1, (T0, T1, T2, T3, T4, T5, T6)>
@@ -479,6 +511,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E0, E1, T> ExactBytesEncode for EncoderChain<E0, E1, T>
 where
@@ -570,6 +606,12 @@ where
     fn is_idle(&self) -> bool {
         self.a.is_idle() && self.b.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.a.cancel())?;
+        track!(self.b.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1> ExactBytesEncode for Chain<E0, E1>
 where
@@ -619,6 +661,11 @@ impl<D: Decode> Buffered<D> {
     pub fn inner_mut(&mut self) -> &mut D {
         &mut self.inner
     }
+
+    /// Takes ownership of this instance and returns the inner decoder.
+    pub fn into_inner(self) -> D {
+        self.inner
+    }
 }
 impl<D: Decode + fmt::Debug> fmt::Debug for Buffered<D> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
