@@ -124,6 +124,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<C, F, E> ExactBytesEncode for MapErr<C, F, E>
 where
@@ -250,6 +254,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E, T, F> ExactBytesEncode for MapFrom<E, T, F>
 where
@@ -304,6 +312,10 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<C, T, E, F> ExactBytesEncode for TryMapFrom<C, T, E, F>
 where
@@ -373,6 +385,12 @@ where
     fn is_idle(&self) -> bool {
         self.items.is_none()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        self.items = None;
+        track!(self.inner.cancel())?;
+        Ok(())
+    }
 }
 
 /// Combinator for representing optional decoders.
@@ -449,6 +467,10 @@ impl<E: Encode> Encode for Optional<E> {
     fn is_idle(&self) -> bool {
         self.0.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.0.cancel())
+    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Optional<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -555,6 +577,11 @@ impl<C> Length<C> {
     pub fn inner_mut(&mut self) -> &mut C {
         &mut self.inner
     }
+
+    /// Takes ownership of this instance and returns the inner encoder or decoder.
+    pub fn into_inner(self) -> C {
+        self.inner
+    }
 }
 impl<D: Decode> Decode for Length<D> {
     type Item = D::Item;
@@ -639,6 +666,12 @@ impl<E: Encode> Encode for Length<E> {
     fn is_idle(&self) -> bool {
         self.remaining_bytes == 0
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())?;
+        self.remaining_bytes = 0;
+        Ok(())
+    }
 }
 impl<E: Encode> ExactBytesEncode for Length<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -828,6 +861,11 @@ impl<C> MaxBytes<C> {
     pub fn inner_mut(&mut self) -> &mut C {
         &mut self.inner
     }
+
+    /// Takes ownership of this instance and returns the inner encoder or decoder.
+    pub fn into_inner(self) -> C {
+        self.inner
+    }
 }
 impl<D: Decode> Decode for MaxBytes<D> {
     type Item = D::Item;
@@ -878,6 +916,10 @@ impl<E: Encode> Encode for MaxBytes<E> {
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for MaxBytes<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -968,6 +1010,11 @@ impl<E: Encode> Encode for Padding<E> {
     fn is_idle(&self) -> bool {
         self.eos_reached
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        self.eos_reached = true;
+        Ok(())
+    }
 }
 
 /// Combinator for adding prefix items.
@@ -1025,6 +1072,12 @@ where
     fn is_idle(&self) -> bool {
         self.prefix_encoder.is_idle() && self.body_encoder.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.prefix_encoder.cancel())?;
+        track!(self.body_encoder.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, F> ExactBytesEncode for WithPrefix<E0, E1, F>
 where
@@ -1075,6 +1128,10 @@ impl<E: Encode> Encode for PreEncode<E> {
     fn is_idle(&self) -> bool {
         self.pre_encoded.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.pre_encoded.cancel())
+    }
 }
 impl<E: Encode> ExactBytesEncode for PreEncode<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -1159,6 +1216,10 @@ impl<E: Encode> Encode for Slice<E> {
     fn requiring_bytes(&self) -> ByteCount {
         self.inner.requiring_bytes()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Slice<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -1194,6 +1255,10 @@ impl<E: Encode> Encode for Last<E> {
     fn requiring_bytes(&self) -> ByteCount {
         self.inner.requiring_bytes()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.inner.cancel())
+    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Last<E> {
     fn exact_requiring_bytes(&self) -> u64 {
