@@ -905,6 +905,12 @@ where
     fn is_idle(&self) -> bool {
         self.e0.is_idle() && self.e1.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1> ExactBytesEncode for Tuple2Encoder<E0, E1>
 where
@@ -987,6 +993,13 @@ where
     fn is_idle(&self) -> bool {
         self.e0.is_idle() && self.e1.is_idle() && self.e2.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2> ExactBytesEncode for Tuple3Encoder<E0, E1, E2>
 where
@@ -1082,6 +1095,14 @@ where
     fn is_idle(&self) -> bool {
         self.e0.is_idle() && self.e1.is_idle() && self.e2.is_idle() && self.e3.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        track!(self.e3.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2, E3> ExactBytesEncode for Tuple4Encoder<E0, E1, E2, E3>
 where
@@ -1196,6 +1217,15 @@ where
         self.e0.is_idle() && self.e1.is_idle() && self.e2.is_idle() && self.e3.is_idle()
             && self.e4.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        track!(self.e3.cancel())?;
+        track!(self.e4.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2, E3, E4> ExactBytesEncode for Tuple5Encoder<E0, E1, E2, E3, E4>
 where
@@ -1331,6 +1361,16 @@ where
         self.e0.is_idle() && self.e1.is_idle() && self.e2.is_idle() && self.e3.is_idle()
             && self.e4.is_idle() && self.e5.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        track!(self.e3.cancel())?;
+        track!(self.e4.cancel())?;
+        track!(self.e5.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2, E3, E4, E5> ExactBytesEncode for Tuple6Encoder<E0, E1, E2, E3, E4, E5>
 where
@@ -1506,6 +1546,17 @@ where
         self.e0.is_idle() && self.e1.is_idle() && self.e2.is_idle() && self.e3.is_idle()
             && self.e4.is_idle() && self.e5.is_idle() && self.e6.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        track!(self.e3.cancel())?;
+        track!(self.e4.cancel())?;
+        track!(self.e5.cancel())?;
+        track!(self.e6.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2, E3, E4, E5, E6> ExactBytesEncode for Tuple7Encoder<E0, E1, E2, E3, E4, E5, E6>
 where
@@ -1700,6 +1751,18 @@ where
             && self.e4.is_idle() && self.e5.is_idle() && self.e6.is_idle()
             && self.e7.is_idle()
     }
+
+    fn cancel(&mut self) -> Result<()> {
+        track!(self.e0.cancel())?;
+        track!(self.e1.cancel())?;
+        track!(self.e2.cancel())?;
+        track!(self.e3.cancel())?;
+        track!(self.e4.cancel())?;
+        track!(self.e5.cancel())?;
+        track!(self.e6.cancel())?;
+        track!(self.e7.cancel())?;
+        Ok(())
+    }
 }
 impl<E0, E1, E2, E3, E4, E5, E6, E7> ExactBytesEncode
     for Tuple8Encoder<E0, E1, E2, E3, E4, E5, E6, E7>
